@@ -42,16 +42,25 @@ $userid         = optional_param('id', 0, PARAM_INT);
 $edit           = optional_param('edit', null, PARAM_BOOL);    // Turn editing on and off.
 $reset          = optional_param('reset', null, PARAM_BOOL);
 
-$PAGE->set_url('/user/profile.php', array('id' => $userid));
+// Even if the user didn't supply a userid, we treat page URL as if they did; this is needed so navigation works correctly.
+$userid = $userid ?: $USER->id;
+$PAGE->set_url('/user/profile.php', ['id' => $userid]);
 
 if (!empty($CFG->forceloginforprofiles)) {
     require_login();
     if (isguestuser()) {
         $PAGE->set_context(context_system::instance());
+        $PAGE->set_title(get_string('loginrequired'));
         echo $OUTPUT->header();
-        echo $OUTPUT->confirm(get_string('guestcantaccessprofiles', 'error'),
-                              get_login_url(),
-                              $CFG->wwwroot);
+        echo $OUTPUT->confirm(
+            get_string('guestcantaccessprofiles', 'error'),
+            get_login_url(),
+            $CFG->wwwroot,
+            [
+                'headinglevel' => 1,
+                'confirmtitle' => get_string('loginrequired'),
+            ],
+        );
         echo $OUTPUT->footer();
         die;
     }
@@ -59,7 +68,6 @@ if (!empty($CFG->forceloginforprofiles)) {
     require_login();
 }
 
-$userid = $userid ? $userid : $USER->id;       // Owner of the page.
 if ((!$user = $DB->get_record('user', array('id' => $userid))) || ($user->deleted)) {
     $PAGE->set_context(context_system::instance());
     echo $OUTPUT->header();
@@ -80,7 +88,7 @@ if (!user_can_view_profile($user, null, $context)) {
     // Course managers can be browsed at site level. If not forceloginforprofiles, allow access (bug #4366).
     $struser = get_string('user');
     $PAGE->set_context(context_system::instance());
-    $PAGE->set_title("$SITE->shortname: $struser");  // Do not leak the name.
+    $PAGE->set_title($struser);  // Do not leak the name.
     $PAGE->set_heading($struser);
     $PAGE->set_pagelayout('mypublic');
     $PAGE->add_body_class('limitedwidth');
@@ -94,7 +102,7 @@ if (!user_can_view_profile($user, null, $context)) {
 
 // Get the profile page.  Should always return something unless the database is broken.
 if (!$currentpage = my_get_page($userid, MY_PAGE_PUBLIC)) {
-    print_error('mymoodlesetup');
+    throw new \moodle_exception('mymoodlesetup');
 }
 
 $PAGE->set_context($context);
@@ -140,7 +148,7 @@ if ($PAGE->user_allowed_editing()) {
     if ($reset !== null) {
         if (!is_null($userid)) {
             if (!$currentpage = my_reset_page($userid, MY_PAGE_PUBLIC, 'user-profile')) {
-                print_error('reseterror', 'my');
+                throw new \moodle_exception('reseterror', 'my');
             }
             redirect(new moodle_url('/user/profile.php', array('id' => $userid)));
         }
@@ -157,7 +165,7 @@ if ($PAGE->user_allowed_editing()) {
             // For the page to display properly with the user context header the page blocks need to
             // be copied over to the user context.
             if (!$currentpage = my_copy_page($userid, MY_PAGE_PUBLIC, 'user-profile')) {
-                print_error('mymoodlesetup');
+                throw new \moodle_exception('mymoodlesetup');
             }
             $PAGE->set_context($usercontext);
             $PAGE->set_subpage($currentpage->id);
@@ -203,6 +211,10 @@ profile_view($user, $usercontext);
 echo $OUTPUT->header();
 echo '<div class="userprofile">';
 
+$hiddenfields = [];
+if (!has_capability('moodle/user:viewhiddendetails', $usercontext)) {
+    $hiddenfields = array_flip(explode(',', $CFG->hiddenuserfields));
+}
 if ($user->description && !isset($hiddenfields['description'])) {
     echo '<div class="description">';
     if (!empty($CFG->profilesforenrolledusersonly) && !$currentuser &&
@@ -216,6 +228,7 @@ if ($user->description && !isset($hiddenfields['description'])) {
     echo '</div>';
 }
 
+echo $OUTPUT->heading(get_string('userprofile', 'core_user'), 2, 'sr-only');
 echo $OUTPUT->custom_block_region('content');
 
 // Render custom blocks.
